@@ -32,6 +32,17 @@ class Settings(AppSettings):
     For example: ``COUNTRIES_FLAG_URL = 'flags/16x10/{code_upper}.png'``
     """
 
+    COUNTRIES_COMMON_NAMES = True
+    """
+    Whether to use the common names for some countries, as opposed to the
+    official ISO name.
+
+    Some examples:
+        "Bolivia" instead of "Bolivia, Plurinational State of"
+        "South Korea" instead of "Korea (the Republic of)"
+        "Taiwan" instead of "Taiwan (Province of China)"
+    """
+
     COUNTRIES_OVERRIDE = {}
     """
     A dictionary of names to override the defaults.
@@ -47,5 +58,19 @@ class Settings(AppSettings):
         }
     """
 
+    COUNTRIES_ONLY = {}
+    """
+    Similar to COUNTRIES_OVERRIDE
+    A dictionary of names to include in selection.
+
+    Note that you will need to handle translation of customised country names.
+
+    For example::
+
+        COUNTRIES_ONLY = {
+            'NZ': _('Middle Earth'),
+            'AU': _('Desert'),
+        }
+    """
 
 settings = Settings()
