@@ -8,25 +8,23 @@ except ImportError:
 from django import forms
 from django.db.models.fields import CharField
 from django.utils.encoding import force_text, python_2_unicode_compatible
-from django.utils.functional import lazy, Promise
+from django.utils.functional import lazy
 
-from django_countries import countries, ioc_data
+from django_countries import countries, ioc_data, widgets
 from django_countries.conf import settings
 
 
 @python_2_unicode_compatible
 class Country(object):
     def __init__(self, code, flag_url=None):
-        if not code:
-            raise ValueError("Country code can not be blank")
         self.code = code
         self.flag_url = flag_url
 
     def __str__(self):
-        return force_text(self.code)
+        return force_text(self.code or '')
 
     def __eq__(self, other):
-        return force_text(self) == force_text(other)
+        return force_text(self) == force_text(other or '')
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -68,6 +66,8 @@ class Country(object):
 
     @property
     def flag(self):
+        if not self.code:
+            return ''
         flag_url = self.flag_url
         if flag_url is None:
             flag_url = settings.COUNTRIES_FLAG_URL
@@ -109,11 +109,8 @@ class CountryDescriptor(object):
             raise AttributeError(
                 "The '%s' attribute can only be accessed from %s instances."
                 % (self.field.name, owner.__name__))
-        code = instance.__dict__[self.field.name]
-        if not code:
-            return code
         return Country(
-            code=code,
+            code=instance.__dict__[self.field.name],
             flag_url=self.field.countries_flag_url,
         )
 
@@ -123,24 +120,18 @@ class CountryDescriptor(object):
         instance.__dict__[self.field.name] = value
 
 
-class LazyTypedChoiceField(forms.TypedChoiceField):
+class LazyTypedChoiceField(widgets.LazyChoicesMixin, forms.TypedChoiceField):
     """
     A form TypedChoiceField that respects choices being a lazy object.
     """
+    widget = widgets.LazySelect
 
-    @property
-    def choices(self):
+    def _set_choices(self, value):
         """
-        When it's time to get the choices, if it was a lazy then figure it out
-        now and memoize the result.
+        Also update the widget's choices.
         """
-        if isinstance(self._choices, Promise):
-            self._choices = list(self._choices)
-        return self._choices
-
-    @choices.setter
-    def choices(self, value):
-        self._choices = value
+        super(LazyTypedChoiceField, self)._set_choices(value)
+        self.widget.choices = value
 
 
 class CountryField(CharField):
@@ -175,6 +166,13 @@ class CountryField(CharField):
         value = super(CharField, self).pre_save(*args, **kwargs)
         return self.get_prep_value(value)
 
+    def get_prep_value(self, value):
+        "Returns field's value prepared for saving into a database."
+        # Convert the Country to unicode for database insertion.
+        if value is None or getattr(value, 'code', '') is None:
+            return None
+        return force_text(value)
+
     def deconstruct(self):
         """
         Remove choices from deconstructed field, as this is the country list
@@ -190,8 +188,6 @@ class CountryField(CharField):
         argname = 'choices_form_class'
         if argname not in kwargs:
             kwargs[argname] = LazyTypedChoiceField
-        # if not 'widget' in kwargs:
-        #     kwargs['widget'] = CountrySelectWidget()
         field = super(CharField, self).formfield(**kwargs)
         if not isinstance(field, LazyTypedChoiceField):
             field = self.legacy_formfield(**kwargs)
